<?php

/**
 * Created by PhpStorm.
 * User: Administrator
 * Date: 2019/6/5
 * Time: 15:58
 */
namespace App\Http\Controllers\Post;

use App\Repositories\Post\PostRepository;
use App\Transformers\Post\PostTransformer;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\Controller;
use Illuminate\Validation\Rule;
use League\Fractal\Manager;
use League\Fractal\Pagination\IlluminatePaginatorAdapter;
use League\Fractal\Resource\Collection;

class PostController extends Controller
{
    public function __construct(PostRepository $postRepository)
    {
        $this->postRepository = $postRepository;
    }

    /**
     * 内容列表
     */
    public function index(Request $request)
    {
        $productList = $this->postRepository->lists($request->all());
        $fractal = new Manager();
        $resource = new Collection($productList, new PostTransformer());
        $resource->setPaginator(new IlluminatePaginatorAdapter($productList));
        $data = $fractal->createData($resource)->toArray();
        $data['extra'] = [
            'filters' => [
                'keyword',
                'content',
                'topic_ids',
                'category_ids',
                'is_suggest',
                'created_at',
                'type',
                'sort'
            ],
            'columns' => [
                'id',
                'created_at',
                'uid',
                'topic',
                'content',
                'location',
                'pv',
                'praise_count',
                'share_count',
                'comment_count',
                'collect_count',
                'create_bean',
                'is_suggest'
            ]
        ];
        return $data;
    }

    /**
     * 发布内容
     */
    public function create(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'uid' => 'required|integer',
            'type' => ['required',Rule::in('image', 'video', 'html')],
            'is_suggest' => ['required',Rule::in(0, 1)],
            'img' => 'required|url',
            'video' => 'required_if:type,video|string|url',
            'topic_ids' => 'required|string|max:64',
            'title' => 'nullable|string|max:20',
            'content' => 'required|string|max:20',
            'location' => 'required|string',
            'imgs' => 'required_if:type,image|array|max:9',
            'imgs.*' => 'required|url',
        ]);
        if ($validator->fails()) {
            return $this->response->error($validator->errors()->first(), 500);
        }
        return  $this->postRepository->create($request->all());
    }

    /**
     * 推荐内容
     */
    public function suggest(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required|integer',
        ]);
        if ($validator->fails()) {
            return $this->response->error($validator->errors()->first(), 500);
        }
        return  $this->postRepository->suggest($request->all());
    }

    /**
     * 删除内容
     */
    public function delete(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required|integer',
        ]);
        if ($validator->fails()) {
            return $this->response->error($validator->errors()->first(), 500);
        }
        return  $this->postRepository->delete($request->all());
    }

    /**
     * 隐藏内容
     */
    public function hide(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required|integer',
        ]);
        if ($validator->fails()) {
            return $this->response->error($validator->errors()->first(), 500);
        }
        return  $this->postRepository->hide($request->all());
    }

}